==> kafka-1.1.1-src.tgz: kafka-1.1.1-src/clients/src/main/java/org/apache/kafka/common/security/auth/SslAuthenticationContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.common.security.auth;

import javax.net.ssl.SSLSession;
import java.net.InetAddress;

public class SslAuthenticationContext implements AuthenticationContext {
    private final SSLSession session;
    private final InetAddress clientAddress;

    public SslAuthenticationContext(SSLSession session, InetAddress clientAddress) {
        this.session = session;
        this.clientAddress = clientAddress;
    }

    public SSLSession session() {
        return session;
    }

    @Override
    public SecurityProtocol securityProtocol() {
        return SecurityProtocol.SSL;
    }

    @Override
    public InetAddress clientAddress() {
        return clientAddress;
    }
}

==> kafka-3.9.2-src.tgz: kafka-3.9.2-src/clients/src/main/java/org/apache/kafka/common/security/auth/SslAuthenticationContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.common.security.auth;

import java.net.InetAddress;

import javax.net.ssl.SSLSession;

public class SslAuthenticationContext implements AuthenticationContext {
    private final SSLSession session;
    private final InetAddress clientAddress;
    private final String listenerName;

    public SslAuthenticationContext(SSLSession session, InetAddress clientAddress, String listenerName) {
        this.session = session;
        this.clientAddress = clientAddress;
        this.listenerName = listenerName;
    }

    public SSLSession session() {
        return session;
    }

    @Override
    public SecurityProtocol securityProtocol() {
        return SecurityProtocol.SSL;
    }

    @Override
    public InetAddress clientAddress() {
        return clientAddress;
    }

    @Override
    public String listenerName() {
        return listenerName;
    }
}
